pub fn has_no_modifiers(key: &KeyEvent) -> boolExpand description
Returns whether a key event has no active modifier keys.
Game controls intentionally only react to bare key presses so terminal and operating-system shortcuts such as Alt+Tab or Ctrl+C are never interpreted as game actions.